@@ -44,6 +44,8 @@ class Module:
 
 
 class AlgebraicModule:
+    """Container for algebraic modules"""
+
     def __init__(
         self,
         name: str,
@@ -64,7 +66,8 @@ class AlgebraicModule:
         self.dynamic_variables = dynamic_variables
         self.args = args
 
-    def _check_consistency(self) -> None:
+    def check_consistency(self) -> None:
+        """Check whether all arguments exists and the arity matches"""
         self._check_dynamic_variables()
         self._check_module_args()
 
@@ -92,6 +95,7 @@ class AlgebraicModule:
         return f"{self.function.__name__}({', '.join(self.args)}) -> {self.derived_compounds}"
 
     def keys(self) -> List[str]:
+        """Get all valid keys of the algebraic module"""
         return [
             "function",
             "compounds",
@@ -115,6 +119,7 @@ class AlgebraicModule:
         yield "args", self.args
 
     def copy(self) -> AlgebraicModule:
+        """Create a copy of the module"""
         return copy.deepcopy(self)
 
 
@@ -197,7 +202,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
                 )
         self._algebraic_module_order = module_order
 
-    def _check_module_consistency(self, module: AlgebraicModule) -> None:
+    def _check_module_consistency(self, module: AlgebraicModule, check_ids: bool = True) -> None:
         self._check_for_existence(
             name=module.name,
             check_against=self.get_all_compounds(),
@@ -211,8 +216,9 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             candidates=module.parameters,
             element_type="parameter",
         )
-        self._check_and_insert_ids(module.derived_compounds, context=module.name)
-        module._check_consistency()
+        if check_ids:
+            self._check_and_insert_ids(module.derived_compounds, context=module.name)
+        module.check_consistency()
 
     def add_algebraic_module(
         self,
@@ -323,6 +329,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         """Update an existing reaction."""
         module = self.algebraic_modules[module_name]
         args_have_changed = False
+        derived_have_changed = False
 
         if function is not None:
             patch_lambda_function_name(function=function, name=module_name)
@@ -337,6 +344,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         if derived_compounds is not None:
             self._remove_ids(module.derived_compounds)
             module.derived_compounds = derived_compounds
+            derived_have_changed = True
 
         if modifiers is not None:
             module.modifiers = modifiers
@@ -370,7 +378,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             args = module.args
 
         if check_consistency:
-            self._check_module_consistency(module)
+            self._check_module_consistency(module, check_ids=derived_have_changed)
         if sort_modules:
             self._sort_algebraic_modules()
 
@@ -422,26 +430,33 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             self.remove_algebraic_module(module_name=module_name)
 
     def get_algebraic_module(self, module_name: str) -> AlgebraicModule:
+        """Return the algebraic module"""
         return self.algebraic_modules[module_name]
 
     def get_algebraic_module_function(
         self, module_name: str
     ) -> Union[Callable[..., float], Callable[..., Iterable[float]]]:
+        """Return the function of the algebraic module"""
         return self.algebraic_modules[module_name].function
 
     def get_algebraic_module_compounds(self, module_name: str) -> List[str]:
+        """Return the compounds of the algebraic module"""
         return list(self.algebraic_modules[module_name].compounds)
 
     def get_algebraic_module_derived_compounds(self, module_name: str) -> List[str]:
+        """Return the derived compounds of the algebraic module"""
         return list(self.algebraic_modules[module_name].derived_compounds)
 
     def get_algebraic_module_modifiers(self, module_name: str) -> List[str]:
+        """Return the modifiers of the algebraic module"""
         return list(self.algebraic_modules[module_name].modifiers)
 
     def get_algebraic_module_parameters(self, module_name: str) -> List[str]:
+        """Return the parameters of the algebraic module"""
         return list(self.algebraic_modules[module_name].parameters)
 
     def get_algebraic_module_args(self, module_name: str) -> List[str]:
+        """Return the arguments of the algebraic module function"""
         return list(self.algebraic_modules[module_name].args)
 
     ##########################################################################
@@ -468,7 +483,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             try:
                 derived_values = module.function(*(args[arg] for arg in module.args))
             except KeyError as e:
-                raise KeyError(f"Could not find argument {e} for module {name}")
+                raise KeyError(f"Could not find argument {e} for module {name}") from e
             derived_compounds = dict(
                 zip(
                     module.derived_compounds,
@@ -543,7 +558,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_algebraic_modules(self, *, sbml_model: libsbml.Model) -> None:
+    def _create_sbml_algebraic_modules(self, *, _sbml_model: libsbml.Model) -> None:
         """Convert the algebraic modules their sbml equivalent.
 
         Notes
