@@ -1,11 +1,11 @@
 """Write me."""
 from __future__ import annotations
 
-import inspect as inspect
+import inspect
 import re
 import subprocess
 import warnings
-from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, Callable, Optional, Type, Union
 
 RE_LAMBDA_FUNC = re.compile(r".*(lambda)(.+?):(.*?)")
 RE_LAMBDA_RATE_FUNC = re.compile(r".*(lambda)(.+?):(.*?),")
@@ -18,9 +18,9 @@ SBML_DOT = "__SBML_DOT__"
 def warning_on_one_line(
     message: Union[Warning, str],
     category: Type[Warning],
-    filename: str,
-    lineno: int,
-    line: Optional[int] = None,
+    _filename: str,
+    _lineno: int,
+    _line: Optional[int] = None,
 ) -> str:  # type: ignore
     """Format warnings to only show the message."""
     return f"{category.__name__}: {message}\n"
@@ -35,6 +35,7 @@ warnings.formatwarning = warning_on_one_line  # type: ignore
 
 
 def check_function_arity(function: Callable, arity: int) -> bool:
+    """Check if the amount of arguments given fits the argument count of the function"""
     argspec = inspect.getfullargspec(function)
     # Give up on *args functions
     if argspec.varargs is not None:
@@ -114,7 +115,7 @@ def get_formatted_function_source_code(function_name: str, function: Callable, f
             )
         else:
             raise ValueError("Can only handle rate or module functions")
-    blacked_string = subprocess.run(["black", "-c", source], stdout=subprocess.PIPE)
+    blacked_string = subprocess.run(["black", "--fast", "--code", source], stdout=subprocess.PIPE, check=True)
     return blacked_string.stdout.decode("utf-8").strip()  # Removing new lines
 
 
