@@ -1,3 +1,5 @@
+"""Interface for integrators"""
+
 from abc import ABC, abstractmethod
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
@@ -5,12 +7,17 @@ import numpy as np
 
 
 class AbstractIntegrator(ABC):
+    """Interface for integrators"""
+
     def __init__(self, rhs: Callable, y0: Union[np.ndarray, List[float]]) -> None:
         self.kwargs: Dict[str, Any] = {}
+        self.rhs = rhs
+        self.y0 = y0
 
     @abstractmethod
     def reset(self) -> None:
-        pass
+        """Reset the integrator and simulator state"""
+        ...
 
     @abstractmethod
     def _simulate(
@@ -21,7 +28,7 @@ class AbstractIntegrator(ABC):
         time_points: Optional[List[float]] = None,
         **integrator_kwargs: Dict[str, Any],
     ) -> Tuple[Optional[List[float]], Optional[List[float]]]:
-        pass
+        ...
 
     @abstractmethod
     def _simulate_to_steady_state(
@@ -31,8 +38,9 @@ class AbstractIntegrator(ABC):
         integrator_kwargs: Dict[str, Any],
         simulation_kwargs: Dict[str, Any],
     ) -> Tuple[Optional[List[float]], Optional[List[float]]]:
-        pass
+        ...
 
     @abstractmethod
     def get_integrator_kwargs(self) -> Dict[str, Any]:
-        pass
+        """Get possible integration settings"""
+        ...
