@@ -8,7 +8,7 @@ import libsbml
 import numpy as np
 import pandas as pd
 
-from ...core import BaseModel, CompoundMixin, RateMixin, StoichiometricMixin
+from ...core import BaseModel, CompoundMixin, StoichiometricMixin
 from ...core.ratemixin import RateMeta
 from ...core.utils import convert_id_to_sbml
 from . import _AbstractStoichiometricModel
@@ -20,6 +20,8 @@ def relative_label_flux(substrate: float, v_ss: float) -> float:
 
 
 class LinearRate:
+    """Some docstring"""
+
     def __init__(
         self,
         base_name: str,
@@ -27,6 +29,9 @@ class LinearRate:
     ):
         self.base_name = base_name
         self.substrate = substrate
+        self._y_ss = None
+        self._v_ss = None
+        self._external_label = None
 
     def __repr__(self) -> str:
         return repr(self.__dict__)
@@ -35,6 +40,7 @@ class LinearRate:
         return f"LinearRate(base_name={self.base_name}, substrate={self.substrate}"
 
     def keys(self) -> List[str]:
+        """Some docstring"""
         return [
             "base_name",
             "substrate",
@@ -71,8 +77,7 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         """Returns a list of all label isotopomers of the compound."""
         if num_labels > 0:
             return [f"{base_name}__{i}" for i in range(num_labels)]
-        else:
-            raise ValueError(f"Compound {base_name} must have labels")
+        raise ValueError(f"Compound {base_name} must have labels")
 
     def add_compound(self, compound: str, num_labels: int) -> None:  # type: ignore
         """Add a label-containing compound to the model."""
@@ -138,9 +143,11 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         self.meta_info.setdefault("rates", {}).setdefault(rate_name, RateMeta(**meta_info))
 
     def remove_rate(self, rate_name: str) -> None:
+        """Some docstring"""
         del self.rates[rate_name]
 
     def get_rate_names(self) -> List[str]:
+        """Some docstring"""
         return list(self.rates.keys())
 
     @staticmethod
@@ -172,10 +179,9 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         diff = len(labelmap) - len(substrates)
         if diff < 0:
             raise ValueError(f"Labelmap 'missing' {abs(diff)} label(s)")
-        elif diff > 0:
-            warnings.warn(f"Added external label influx for reaction {rate_name}")
-            for _ in range(diff):
-                substrates.append("EXT")
+        warnings.warn(f"Added external label influx for reaction {rate_name}")
+        for _ in range(diff):
+            substrates.append("EXT")
 
     @staticmethod
     def _map_substrates_to_labelmap(*, substrates: List[str], labelmap: List[int]) -> List[str]:
@@ -263,7 +269,6 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         y: Union[Iterable[float], Dict[str, float]],
         v_ss: Dict[str, float],
         external_label: float = 1.0,
-        t: float = 0.0,
     ) -> Dict[str, float]:
         """Calculate the fluxes at time point(s) t."""
         if not isinstance(y, dict):
@@ -275,18 +280,16 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         y: Dict[str, float],
         v_ss: Dict[str, float],
         external_label: float = 1.0,
-        t: float = 0.0,
     ) -> np.ndarray:
         """Calculate the fluxes at time point(s) t."""
         return np.array(
-            [
-                i
-                for i in self.get_fluxes_dict(
+            list(
+                self.get_fluxes_dict(
                     y=y,
                     v_ss=v_ss,
                     external_label=external_label,
                 ).values()
-            ]
+            )
         ).T
 
     def get_fluxes_df(
@@ -312,14 +315,14 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         else:
             t_array = t
         return pd.DataFrame(
-            data=self.get_fluxes_dict(y=y, v_ss=v_ss, external_label=external_label, t=t),
+            data=self.get_fluxes_dict(y=y, v_ss=v_ss, external_label=external_label),
             index=t_array,
             columns=self.get_rate_names(),
         )
 
     # This can't get keyword-only arguments, as the integrators are calling it with
     # positional arguments
-    def _get_rhs(self, t: float, y_labels: List[float]) -> List[float]:  # type: ignore[override]
+    def _get_rhs(self, _t: float, y_labels: List[float]) -> List[float]:  # type: ignore[override]
         fcd = dict(zip(self.compounds, y_labels))
         dxdt: Dict[str, float] = {i: 0.0 for i in self.compounds}
 
@@ -360,7 +363,7 @@ class LinearLabelModel(_AbstractStoichiometricModel):
         self._external_label = external_label
         if isinstance(y_labels, dict):
             y_labels = cast(List[float], [y_labels[i] for i in self.compounds])
-        return dict(zip(self.compounds, self._get_rhs(t=t, y_labels=y_labels)))
+        return dict(zip(self.compounds, self._get_rhs(_t=t, y_labels=y_labels)))
 
     ##########################################################################
     # SBML functions
