@@ -1,3 +1,5 @@
+"""Some docstring"""
+
 from __future__ import annotations
 
 from functools import reduce
@@ -5,6 +7,7 @@ from operator import mul
 
 
 def constant(k: float) -> float:
+    """Some docstring"""
     return k
 
 
@@ -14,22 +17,27 @@ def constant(k: float) -> float:
 
 
 def mass_action_1(S1: float, k_fwd: float) -> float:
+    """Some docstring"""
     return k_fwd * S1
 
 
 def mass_action_2(S1: float, S2: float, k_fwd: float) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2
 
 
 def mass_action_3(S1: float, S2: float, S3: float, k_fwd: float) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3
 
 
 def mass_action_4(S1: float, S2: float, S3: float, S4: float, k_fwd: float) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 * S4
 
 
 def mass_action_variable(*args: float) -> float:
+    """Some docstring"""
     return reduce(mul, args, 1)
 
 
@@ -38,87 +46,195 @@ def mass_action_variable(*args: float) -> float:
 ###############################################################################
 
 
-def reversible_mass_action_1_1(S1: float, P1: float, k_fwd: float, k_bwd: float) -> float:
+def reversible_mass_action_1_1(
+    S1: float,
+    P1: float,
+    k_fwd: float,
+    k_bwd: float,
+) -> float:
+    """Some docstring"""
     return k_fwd * S1 - k_bwd * P1
 
 
-def reversible_mass_action_2_1(S1: float, S2: float, P1: float, k_fwd: float, k_bwd: float) -> float:
+def reversible_mass_action_2_1(
+    S1: float,
+    S2: float,
+    P1: float,
+    k_fwd: float,
+    k_bwd: float,
+) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 - k_bwd * P1
 
 
 def reversible_mass_action_3_1(
-    S1: float, S2: float, S3: float, P1: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    S3: float,
+    P1: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 - k_bwd * P1
 
 
 def reversible_mass_action_4_1(
-    S1: float, S2: float, S3: float, S4: float, P1: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    S3: float,
+    S4: float,
+    P1: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 * S4 - k_bwd * P1
 
 
-def reversible_mass_action_1_2(S1: float, P1: float, P2: float, k_fwd: float, k_bwd: float) -> float:
+def reversible_mass_action_1_2(
+    S1: float,
+    P1: float,
+    P2: float,
+    k_fwd: float,
+    k_bwd: float,
+) -> float:
+    """Some docstring"""
     return k_fwd * S1 - k_bwd * P1 * P2
 
 
 def reversible_mass_action_2_2(
-    S1: float, S2: float, P1: float, P2: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    P1: float,
+    P2: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 - k_bwd * P1 * P2
 
 
 def reversible_mass_action_3_2(
-    S1: float, S2: float, S3: float, P1: float, P2: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    S3: float,
+    P1: float,
+    P2: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 - k_bwd * P1 * P2
 
 
 def reversible_mass_action_4_2(
-    S1: float, S2: float, S3: float, S4: float, P1: float, P2: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    S3: float,
+    S4: float,
+    P1: float,
+    P2: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 * S4 - k_bwd * P1 * P2
 
 
 def reversible_mass_action_1_3(
-    S1: float, P1: float, P2: float, P3: float, k_fwd: float, k_bwd: float
+    S1: float,
+    P1: float,
+    P2: float,
+    P3: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 - k_bwd * P1 * P2 * P3
 
 
 def reversible_mass_action_2_3(
-    S1: float, S2: float, P1: float, P2: float, P3: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    P1: float,
+    P2: float,
+    P3: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 - k_bwd * P1 * P2 * P3
 
 
 def reversible_mass_action_3_3(
-    S1: float, S2: float, S3: float, P1: float, P2: float, P3: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    S3: float,
+    P1: float,
+    P2: float,
+    P3: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 - k_bwd * P1 * P2 * P3
 
 
 def reversible_mass_action_4_3(
-    S1: float, S2: float, S3: float, S4: float, P1: float, P2: float, P3: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    S3: float,
+    S4: float,
+    P1: float,
+    P2: float,
+    P3: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 * S4 - k_bwd * P1 * P2 * P3
 
 
 def reversible_mass_action_1_4(
-    S1: float, P1: float, P2: float, P3: float, P4: float, k_fwd: float, k_bwd: float
+    S1: float,
+    P1: float,
+    P2: float,
+    P3: float,
+    P4: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 - k_bwd * P1 * P2 * P3 * P4
 
 
 def reversible_mass_action_2_4(
-    S1: float, S2: float, P1: float, P2: float, P3: float, P4: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    P1: float,
+    P2: float,
+    P3: float,
+    P4: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 - k_bwd * P1 * P2 * P3 * P4
 
 
 def reversible_mass_action_3_4(
-    S1: float, S2: float, S3: float, P1: float, P2: float, P3: float, P4: float, k_fwd: float, k_bwd: float
+    S1: float,
+    S2: float,
+    S3: float,
+    P1: float,
+    P2: float,
+    P3: float,
+    P4: float,
+    k_fwd: float,
+    k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 - k_bwd * P1 * P2 * P3 * P4
 
 
@@ -134,10 +250,12 @@ def reversible_mass_action_4_4(
     k_fwd: float,
     k_bwd: float,
 ) -> float:
+    """Some docstring"""
     return k_fwd * S1 * S2 * S3 * S4 - k_bwd * P1 * P2 * P3 * P4
 
 
 def reversible_mass_action_variable_1(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:1]
     products = metabolites[1:]
@@ -145,6 +263,7 @@ def reversible_mass_action_variable_1(*args: float) -> float:
 
 
 def reversible_mass_action_variable_2(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:2]
     products = metabolites[2:]
@@ -152,6 +271,7 @@ def reversible_mass_action_variable_2(*args: float) -> float:
 
 
 def reversible_mass_action_variable_3(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:3]
     products = metabolites[3:]
@@ -159,6 +279,7 @@ def reversible_mass_action_variable_3(*args: float) -> float:
 
 
 def reversible_mass_action_variable_4(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:4]
     products = metabolites[4:]
@@ -166,6 +287,7 @@ def reversible_mass_action_variable_4(*args: float) -> float:
 
 
 def reversible_mass_action_variable_5(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:5]
     products = metabolites[5:]
@@ -173,6 +295,7 @@ def reversible_mass_action_variable_5(*args: float) -> float:
 
 
 def reversible_mass_action_variable_6(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:6]
     products = metabolites[6:]
@@ -180,6 +303,7 @@ def reversible_mass_action_variable_6(*args: float) -> float:
 
 
 def reversible_mass_action_variable_7(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:7]
     products = metabolites[7:]
@@ -187,6 +311,7 @@ def reversible_mass_action_variable_7(*args: float) -> float:
 
 
 def reversible_mass_action_variable_8(*args: float) -> float:
+    """Some docstring"""
     *metabolites, k_fwd, k_bwd = args
     substrates = metabolites[:8]
     products = metabolites[8:]
@@ -199,38 +324,47 @@ def reversible_mass_action_variable_8(*args: float) -> float:
 
 
 def michaelis_menten(S: float, vmax: float, km: float) -> float:
+    """Some docstring"""
     return S * vmax / (S + km)
 
 
 def competitive_inhibition(S: float, I: float, vmax: float, km: float, ki: float) -> float:
+    """Some docstring"""
     return vmax * S / (S + km * (1 + I / ki))
 
 
 def competitive_activation(S: float, A: float, vmax: float, km: float, ka: float) -> float:
+    """Some docstring"""
     return vmax * S / (S + km * (1 + ka / A))
 
 
 def uncompetitive_inhibition(S: float, I: float, vmax: float, km: float, ki: float) -> float:
+    """Some docstring"""
     return vmax * S / (S * (1 + I / ki) + km)
 
 
 def uncompetitive_activation(S: float, A: float, vmax: float, km: float, ka: float) -> float:
+    """Some docstring"""
     return vmax * S / (S * (1 + ka / A) + km)
 
 
 def noncompetitive_inhibition(S: float, I: float, vmax: float, km: float, ki: float) -> float:
+    """Some docstring"""
     return vmax * S / ((S + km) * (1 + I / ki))
 
 
 def noncompetitive_activation(S: float, A: float, vmax: float, km: float, ka: float) -> float:
+    """Some docstring"""
     return vmax * S / ((S + km) * (1 + ka / A))
 
 
 def mixed_inhibition(S: float, I: float, vmax: float, km: float, ki: float) -> float:
+    """Some docstring"""
     return vmax * S / (S * (1 + I / ki) + km * (1 + I / ki))
 
 
 def mixed_activation(S: float, A: float, vmax: float, km: float, ka: float) -> float:
+    """Some docstring"""
     return vmax * S / (S * (1 + ka / A) + km * (1 + ka / A))
 
 
@@ -240,26 +374,54 @@ def mixed_activation(S: float, A: float, vmax: float, km: float, ka: float) -> f
 
 
 def reversible_michaelis_menten(
-    S: float, P: float, vmax_fwd: float, vmax_bwd: float, kms: float, kmp: float
+    S: float,
+    P: float,
+    vmax_fwd: float,
+    vmax_bwd: float,
+    kms: float,
+    kmp: float,
 ) -> float:
+    """Some docstring"""
     return (vmax_fwd * S / kms - vmax_bwd * P / kmp) / (1 + S / kms + P / kmp)
 
 
 def reversible_uncompetitive_inhibition(
-    S: float, P: float, I: float, vmax_fwd: float, vmax_bwd: float, kms: float, kmp: float, ki: float
+    S: float,
+    P: float,
+    I: float,
+    vmax_fwd: float,
+    vmax_bwd: float,
+    kms: float,
+    kmp: float,
+    ki: float,
 ) -> float:
+    """Some docstring"""
     return (vmax_fwd * S / kms - vmax_bwd * P / kmp) / (1 + (S / kms) + (P / kmp) * (1 + I / ki))
 
 
 def reversible_noncompetitive_inhibition(
-    S: float, P: float, I: float, vmax_fwd: float, vmax_bwd: float, kms: float, kmp: float, ki: float
+    S: float,
+    P: float,
+    I: float,
+    vmax_fwd: float,
+    vmax_bwd: float,
+    kms: float,
+    kmp: float,
+    ki: float,
 ) -> float:
+    """Some docstring"""
     return (vmax_fwd * S / kms - vmax_bwd * P / kmp) / ((1 + S / kms + P / kmp) * (1 + I / ki))
 
 
 def reversible_michaelis_menten_keq(
-    S: float, P: float, vmax_fwd: float, kms: float, kmp: float, keq: float
+    S: float,
+    P: float,
+    vmax_fwd: float,
+    kms: float,
+    kmp: float,
+    keq: float,
 ) -> float:
+    """Some docstring"""
     return vmax_fwd / kms * (S - P / keq) / (1 + S / kms + P / kmp)
 
 
@@ -273,6 +435,7 @@ def reversible_uncompetitive_inhibition_keq(
     ki: float,
     keq: float,
 ) -> float:
+    """Some docstring"""
     return vmax_fwd / kms * (S - P / keq) / (1 + (S / kms) + (P / kmp) * (1 + I / ki))
 
 
@@ -286,6 +449,7 @@ def reversible_noncompetitive_inhibition_keq(
     ki: float,
     keq: float,
 ) -> float:
+    """Some docstring"""
     return vmax_fwd / kms * (S - P / keq) / ((1 + S / kms + P / kmp) * (1 + I / ki))
 
 
@@ -294,7 +458,15 @@ def reversible_noncompetitive_inhibition_keq(
 ###############################################################################
 
 
-def ordered_2(A: float, B: float, vmax: float, kmA: float, kmB: float, kiA: float) -> float:
+def ordered_2(
+    A: float,
+    B: float,
+    vmax: float,
+    kmA: float,
+    kmB: float,
+    kiA: float,
+) -> float:
+    """Some docstring"""
     return vmax * A * B / (A * B + kmB * A + kmA * B + kiA * kmB)
 
 
@@ -314,6 +486,7 @@ def ordered_2_2(
     kiP: float,
     kiQ: float,
 ) -> float:
+    """Some docstring"""
     nominator = vmaxf * A * B / (kiA * kmB) - vmaxr * P * Q / (kmP * kiQ)
     denominator = (
         1
@@ -331,7 +504,15 @@ def ordered_2_2(
     return nominator / denominator
 
 
-def random_order_2(A: float, B: float, vmax: float, kmA: float, kmB: float, kiA: float) -> float:
+def random_order_2(
+    A: float,
+    B: float,
+    vmax: float,
+    kmA: float,
+    kmB: float,
+    kiA: float,
+) -> float:
+    """Some docstring"""
     return vmax * A * B / (A * B + kmB * A + kmA * B + kiA * kmB)
 
 
@@ -349,6 +530,7 @@ def random_order_2_2(
     kiP: float,
     kiQ: float,
 ) -> float:
+    """Some docstring"""
     nominator = vmaxf * A * B / (kiA * kmB) - vmaxr * P * Q / (kmP * kiQ)
     denominator = (
         1 + (A / kiA) + (B / kiB) + (P / kiP) + (Q / kiQ) + (A * B / (kiA * kmB)) + (P * Q / (kmP * kiQ))
@@ -356,17 +538,42 @@ def random_order_2_2(
     return nominator / denominator
 
 
-def ping_pong_2(A: float, B: float, vmax: float, kmA: float, kmB: float) -> float:
+def ping_pong_2(
+    A: float,
+    B: float,
+    vmax: float,
+    kmA: float,
+    kmB: float,
+) -> float:
+    """Some docstring"""
     return vmax * A * B / (A * B + kmA * B + kmB * A)
 
 
-def ping_pong_3(A: float, B: float, C: float, vmax: float, kmA: float, kmB: float, kmC: float) -> float:
+def ping_pong_3(
+    A: float,
+    B: float,
+    C: float,
+    vmax: float,
+    kmA: float,
+    kmB: float,
+    kmC: float,
+) -> float:
+    """Some docstring"""
     return (vmax * A * B * C) / (A * B * C + (kmA * B * C) + (kmB * A * C) + (kmC * A * B))
 
 
 def ping_pong_4(
-    A: float, B: float, C: float, D: float, vmax: float, kmA: float, kmB: float, kmC: float, kmD: float
+    A: float,
+    B: float,
+    C: float,
+    D: float,
+    vmax: float,
+    kmA: float,
+    kmB: float,
+    kmC: float,
+    kmD: float,
 ) -> float:
+    """Some docstring"""
     return (vmax * A * B * C * D) / (
         A * B * C * D + (kmA * B * C * D) + (kmB * A * C * D) + (kmC * A * B * D) + (kmD * A * B * C)
     )
@@ -378,6 +585,7 @@ def ping_pong_4(
 
 
 def hill(S: float, vmax: float, kd: float, n: float) -> float:
+    """Some docstring"""
     return vmax * S ** n / (kd + S ** n)
 
 
