@@ -1,3 +1,5 @@
+"""Some docstring"""
+
 from __future__ import annotations
 
 import copy
@@ -59,8 +61,7 @@ class Parser:
     def _raise_or_warn(self, msg: str, error: Type[RuntimeError]) -> None:
         if self.raise_warnings:
             raise error(msg)
-        else:
-            warnings.warn(msg)
+        warnings.warn(msg)
 
     def __init__(self, file: Union[str, Path], raise_warnings: bool = True) -> None:
         self.raise_warnings = raise_warnings
@@ -110,6 +111,7 @@ class Parser:
     ###############################################################################
 
     def parse_constraints(self) -> None:
+        """Some docstring"""
         if len(self.sbml_model.getListOfConstraints()) > 0:
             warnings.warn(
                 "modelbase does not support model constraints. "
@@ -117,10 +119,12 @@ class Parser:
             )
 
     def parse_events(self) -> None:
+        """Some docstring"""
         if len(self.sbml_model.getListOfEvents()) > 0:
             self._raise_or_warn("modelbase does not currently support events.", NotImplementedError)
 
     def parse_units(self) -> None:
+        """Some docstring"""
         for unit_definition in self.sbml_model.getListOfUnitDefinitions():
             composite_id = unit_definition.getId()
             local_units = []
@@ -139,6 +143,7 @@ class Parser:
             )
 
     def parse_initial_assignments(self) -> None:
+        """Some docstring"""
         for assignment in self.sbml_model.getListOfInitialAssignments():
             sbml_id = assignment.getId()
             node = assignment.getMath()
@@ -157,6 +162,7 @@ class Parser:
             )
 
     def parse_parameters(self) -> None:
+        """Some docstring"""
         for parameter in self.sbml_model.getListOfParameters():
             parameter_id = parameter.getId()
             self.parsed_parameters[parameter_id] = Parameter(
@@ -167,6 +173,7 @@ class Parser:
             )
 
     def parse_compartments(self) -> None:
+        """Some docstring"""
         for compartment in self.sbml_model.getListOfCompartments():
             sbml_id = compartment.getId()
             size = compartment.getSize()
@@ -182,6 +189,7 @@ class Parser:
             )
 
     def parse_species(self) -> None:
+        """Some docstring"""
         for compound in self.sbml_model.getListOfSpecies():
             if bool(compound.getConversionFactor()):
                 self._raise_or_warn("Conversion factors are not supported", NotImplementedError)
@@ -213,6 +221,7 @@ class Parser:
             )
 
     def parse_functions(self) -> None:
+        """Some docstring"""
         for func in self.sbml_model.getListOfFunctionDefinitions():
             func_name = func.getName()
             sbml_id = func.getId()
@@ -237,6 +246,7 @@ class Parser:
             )
 
     def _parse_algebraic_rule(self, rule: libsbml.AlgebraicRule) -> None:
+        """Some docstring"""
         node = rule.getMath()
         if node is None:
             return None
@@ -257,6 +267,7 @@ class Parser:
         )
 
     def _parse_assignment_rule(self, rule: libsbml.AssignmentRule) -> None:
+        """Some docstring"""
         node = rule.getMath()
         if node is None:
             return None
@@ -285,6 +296,7 @@ class Parser:
         )
 
     def _parse_rate_rule(self, rule: libsbml.RateRule) -> None:
+        """Some docstring"""
         sbml_id = rule.getMetaId()
         derived_compound = rule.getId()
         if sbml_id is None or sbml_id == "":
@@ -356,6 +368,7 @@ class Parser:
         return parameters_to_update
 
     def parse_reactions(self) -> None:
+        """Some docstring"""
         for reaction in self.sbml_model.getListOfReactions():
             sbml_id = reaction.getId()
             kinetic_law = reaction.getKineticLaw()
@@ -412,6 +425,7 @@ class Parser:
             )
 
     def _parse(self) -> None:
+        """Some docstring"""
         self.parse_functions()
         self.parse_units()
         self.parse_compartments()
@@ -439,6 +453,7 @@ class Parser:
             self.produced_compounds.add(rate.derived_compound)
 
     def _move_parameter_to_variables(self, parameter: Parameter) -> None:
+        """Some docstring"""
         self.converted_variables[parameter.sbml_id] = Compound(
             sbml_id=parameter.sbml_id,
             name=parameter.name,
@@ -452,6 +467,7 @@ class Parser:
         )
 
     def _move_compartment_to_constants(self, compartment: Compartment) -> None:
+        """Some docstring"""
         self.converted_constants[compartment.sbml_id] = Parameter(
             sbml_id=compartment.sbml_id,
             name=compartment.name,
@@ -460,6 +476,7 @@ class Parser:
         )
 
     def _move_compartment_to_variables(self, compartment: Compartment) -> None:
+        """Some docstring"""
         self.converted_variables[compartment.sbml_id] = Compound(
             sbml_id=compartment.sbml_id,
             name=compartment.name,
@@ -473,6 +490,7 @@ class Parser:
         )
 
     def _move_compound_to_constants(self, compound: Compound) -> None:
+        """Some docstring"""
         self.converted_constants[compound.sbml_id] = Parameter(
             sbml_id=compound.sbml_id,
             name=compound.name,
@@ -481,6 +499,7 @@ class Parser:
         )
 
     def convert_parameters(self) -> None:
+        """Some docstring"""
         for sbml_id, parameter in self.parsed_parameters.items():
             if not parameter.is_constant:
                 self._move_parameter_to_variables(parameter=parameter)
@@ -488,6 +507,7 @@ class Parser:
                 self.converted_constants[sbml_id] = parameter
 
     def convert_compartments(self) -> None:
+        """Some docstring"""
         for compartment in self.parsed_compartments.values():
             if compartment.is_constant:
                 self._move_compartment_to_constants(compartment=compartment)
@@ -495,6 +515,7 @@ class Parser:
                 self._move_compartment_to_variables(compartment=compartment)
 
     def convert_compounds(self) -> None:
+        """Some docstring"""
         for sbml_id, compound in self.parsed_species.items():
             if compound.is_constant:
                 self._move_compound_to_constants(compound=compound)
@@ -502,6 +523,7 @@ class Parser:
                 self.converted_variables[sbml_id] = compound
 
     def _replace_function_with_operators(self, algebraic_rule: AlgebraicRule) -> None:
+        """Some docstring"""
         rule_body = algebraic_rule.function_body
         if "," not in rule_body:
             return None
@@ -520,6 +542,7 @@ class Parser:
         algebraic_rule.function_body = rule_body
 
     def _convert_algebraic_to_assignment_rule(self, rule: AlgebraicRule) -> None:
+        """Some docstring"""
         parsed_args = rule.parsed_args
         # isolate derived_compound
         explained_args = self.produced_compounds | set(self.converted_constants)
@@ -561,10 +584,12 @@ class Parser:
         )
 
     def convert_algebraic_rules(self) -> None:
+        """Some docstring"""
         for rule in self.parsed_algebraic_rules.values():
             self._convert_algebraic_to_assignment_rule(rule=rule)
 
     def convert_assignment_rules(self) -> None:
+        """Some docstring"""
         for sbml_id, rule in self.parsed_assignment_rules.items():
             parsed_args = rule.parsed_args
             compounds = [i for i in parsed_args if i in self.converted_variables]
@@ -586,6 +611,7 @@ class Parser:
             )
 
     def _convert_rate_rule_to_reaction(self, rule: RateRule) -> None:
+        """Some docstring"""
         derived_compound = rule.derived_compound
         if derived_compound in self.parsed_compartments:
             self._raise_or_warn("Dynamic compartments are unsupported", NotImplementedError)
@@ -636,13 +662,16 @@ class Parser:
         )
 
     def convert_rate_rules(self) -> None:
+        """Some docstring"""
         for rule_id, rule in self.parsed_rate_rules.items():
             self._convert_rate_rule_to_reaction(rule=rule)
 
     def convert_reactions(self) -> None:
+        """Some docstring"""
         self.converted_reactions.update(copy.deepcopy(self.parsed_reactions))
 
     def convert_initial_assignments(self) -> None:
+        """Some docstring"""
         for target, assignment in self.parsed_initial_assignments.items():
             if target in self.converted_constants:
                 self.converted_derived_constants[target] = assignment
@@ -650,6 +679,7 @@ class Parser:
                 self.converted_initial_assignments[target] = assignment
 
     def _collect_and_convert(self) -> None:
+        """Some docstring"""
         self.collect_slow_changing_compounds()
 
         # constants and variables
@@ -673,11 +703,13 @@ class Parser:
     ###############################################################################
 
     def handle_functions(self) -> None:
+        """Some docstring"""
         for sbml_id, function in self.parsed_functions.items():
             function.function_body = _simplify_function_body(function_body=function.function_body)
             self.converted_functions[sbml_id] = function
 
     def _delete_derived_compounds_from_compounds(self) -> None:
+        """Some docstring"""
         for compound in self.derived_compounds:
             if compound in self.converted_variables:
                 del self.converted_variables[compound]
@@ -709,6 +741,7 @@ class Parser:
         self.converted_algebraic_modules = sorted_modules
 
     def _set_module_func_args(self, module: AssignmentRule) -> None:
+        """Some docstring"""
         parsed_args = module.parsed_args
         compounds = [i for i in parsed_args if i in self.converted_variables]
         parameters = [i for i in parsed_args if i in self.converted_constants]
@@ -723,6 +756,7 @@ class Parser:
         module.modifiers = modifiers_
 
     def handle_algebraic_modules(self) -> None:
+        """Some docstring"""
         self._delete_derived_compounds_from_compounds()
         for module in self.converted_algebraic_modules.values():
             # watch out for species reference
@@ -791,6 +825,7 @@ class Parser:
         reaction.function_body = function_body
 
     def _set_reaction_func_args(self, reaction: Reaction) -> None:
+        """Some docstring"""
         all_parameters = set(self.converted_constants)
         parsed_args = reaction.parsed_args
         # remove unused (simplify after convert to concentration)
@@ -813,6 +848,7 @@ class Parser:
         reaction.modifiers = modifiers_
 
     def handle_reactions(self) -> None:
+        """Some docstring"""
         for sbml_id, reaction in self.converted_reactions.items():
             self._set_reaction_stoichiometries(reaction=reaction)
             self._convert_substance_amount_to_concentration(reaction=reaction)
@@ -820,6 +856,7 @@ class Parser:
             self._set_reaction_func_args(reaction=reaction)
 
     def handle_initial_assignments(self) -> None:
+        """Some docstring"""
         for assignment in self.converted_initial_assignments.values():
             derived_parameter = assignment.derived_parameter
             if derived_parameter in self.parsed_species:
@@ -836,6 +873,7 @@ class Parser:
                         assignment.function_args.append(compartment)
 
     def _handle(self) -> None:
+        """Some docstring"""
         self.handle_functions()
         self.handle_algebraic_modules()
         self.handle_reactions()
@@ -862,13 +900,14 @@ class Parser:
         )
         try:
             exec(func_str, globals(), None)
-        except SyntaxError:
-            raise SyntaxError(f"Invalid function definition: {func_str}")
+        except SyntaxError as e:
+            raise SyntaxError(f"Invalid function definition: {func_str}") from e
         python_func = globals()[func.sbml_id]
         python_func.__source__ = func_str
         return python_func  # type: ignore
 
     def build_model_from_sbml(self) -> Tuple[Model, Dict[str, Any]]:
+        """Some docstring"""
         # Do the parsing
         self._parse()
         self._collect_and_convert()
